<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>Додаци</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="15"/>
        <source>Advanced Settings</source>
        <translation>Напредна подешавања</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>&quot;Напредна подешавања&quot; важе само за метод уноса који користи системска подешавања. Ако метод уноса има своја подешавања, важиће његова подешавања.</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="54"/>
        <source>Global Config</source>
        <translation>Глобална конфигурација</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="70"/>
        <source>Add-ons</source>
        <translation>Додаци</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="81"/>
        <source>Keyboard layout</source>
        <translation>Распоред тастатуре</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="151"/>
        <source>Please enter a new shortcut</source>
        <translation>Молимо унесите нову пречицу</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="152"/>
        <source>Move Up</source>
        <translation>Помери горе</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="160"/>
        <source>Move Down</source>
        <translation>Помери доле</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="168"/>
        <source>Settings</source>
        <translation>Подешавања</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="176"/>
        <source>Remove</source>
        <translation>Уклони</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="35"/>
        <source>Add input method</source>
        <translation>Додај метод уноса</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="41"/>
        <source>Search</source>
        <translation>Претрага</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="109"/>
        <source>Find more in App Store</source>
        <translation>Пронађи више у App Store</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="129"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="136"/>
        <source>Add</source>
        <translation>Додај</translation>
    </message>
</context>
<context>
    <name>KeyboardLayout</name>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="16"/>
        <source>Keyboard layout</source>
        <translation>Распоред тастатуре</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="34"/>
        <source>done</source>
        <translation>готово</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="34"/>
        <source>edit</source>
        <translation>уреди</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="57"/>
        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
        <translation>Додајте одговарајући метод уноса у &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Управљање методима уноса&lt;/a&gt; да би распоред тастатуре радио када се додаје или мења.</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="142"/>
        <source>Add new keyboard layout...</source>
        <translation>Додај нови распоред тастатуре...</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutModule</name>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="16"/>
        <source>Keyboard layout</source>
        <translation>Распоред тастатуре</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
        <source>done</source>
        <translation>готово</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
        <source>edit</source>
        <translation>уреди</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="57"/>
        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
        <translation>Додајте одговарајући метод уноса у &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Управљање методима уноса&lt;/a&gt; да би распоред тастатуре радио када се додаје или мења.</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="140"/>
        <source>Add new keyboard layout...</source>
        <translation>Додај нови распоред тастатуре...</translation>
    </message>
</context>
<context>
    <name>LayoutsChooser</name>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="30"/>
        <source>Add new keyboard layout</source>
        <translation>Додај нови распоред тастатуре</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="38"/>
        <source>Search</source>
        <translation>Претрага</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="67"/>
        <source>Current language keyboard layouts</source>
        <translation>Распореди тастатуре тренутног језика</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="90"/>
        <source>Cancel</source>
            <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="97"/>
        <source>Add</source>
        <translation>Додај</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>Управљање методима уноса</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="33"/>
        <source>Add input method</source>
        <translation>Додај метод уноса</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="12"/>
        <location filename="../qml/ShortcutsModule.qml" line="14"/>
        <location filename="../qml/ShortcutsModule.qml" line="151"/>
        <location filename="../qml/ShortcutsModule.qml" line="152"/>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="119"/>
        <source>Shortcuts</source>
        <translation>Пречице</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="134"/>
        <source>Restore Defaults</source>
        <translation>Врати подразумевано</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="200"/>
        <source>Scroll between input methods</source>
        <translation>Мењај између метода уноса</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="230"/>
        <source>Turn on or off input methods</source>
        <translation>Укључи или искључи методе уноса</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="273"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>Укључује или искључује тренутно коришћен метод уноса. Ако се не користи ниједан метод уноса или први метод уноса није тастатура, пребацује се између првог метода уноса и тренутно коришћене тастатуре/метода уноса.</translation>
    </message>
</context>
<context>
    <name>dcc::Locale::dialectNames</name>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="62"/>
        <source>Traditional Chinese (Chinese Hong Kong)</source>
        <translation>Традиционални кинески (кинески Хонг Конг)</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="65"/>
        <source>Traditional Chinese (Chinese Taiwan)</source>
        <translation>Традиционални кинески (кинески Тајван)</translation>
    </message>
</context>
<context>
    <name>dcc::Locale::regionNames</name>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="86"/>
        <source>Taiwan China</source>
        <translation>Тајван Кина</translation>
    </message>
</context>
<context>
    <name>dccV25::KeyboardController</name>
    <message>
        <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
        <source>This shortcut conflicts with [%1]</source>
            <translation>Ова пречица се конфликтује са [%1]</translation>
    </message>
</context>
<context>
    <name>dccV25::ShortcutModel</name>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="248"/>
        <source>System</source>
        <translation>Систем</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="253"/>
        <source>Window</source>
        <translation>Прозор</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="258"/>
        <source>Workspace</source>
        <translation>Радни простор</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="263"/>
        <source>AssistiveTools</source>
        <translation>Помоћни алати</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="268"/>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="339"/>
        <source>Custom</source>
        <translation>Прилагођено</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="394"/>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>Методи уноса</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>Управљање методима уноса, пречице метода уноса, напредна подешавања</translation>
    </message>
</context>
</TS>